@@ -21,11 +21,24 @@ Source: L<http://www.debian.org/doc/manuals/debian-faq/ch-ftparchives.en.html#s-
 
 Philippe "BooK" Bruhat.
 
-Introduced in Acme-MetaSyntactic version 0.20, published on May 2, 2005.
+=head1 CHANGES
+
+=over 4
+
+=item *
+
+2012-05-07 - v1.000
 
 Updated with the new Debian versions since 2007, and
-received its own version number for Acme-MetaSyntactic-Themes version 1.000,
-published on May 7, 2012.
+received its own version number in Acme-MetaSyntactic-Themes version 1.000.
+
+=item *
+
+2005-05-02
+
+Introduced in Acme-MetaSyntactic version 0.20.
+
+=back
 
 =head1 SEE ALSO
 
