@@ -2,7 +2,7 @@ package Acme::MetaSyntactic::linux;
 use strict;
 use Acme::MetaSyntactic::List;
 our @ISA = qw( Acme::MetaSyntactic::List );
-our $VERSION = '1.007';
+our $VERSION = '1.008';
 
 our %Remote = (
     source  => 'http://distrowatch.com/',
@@ -47,6 +47,12 @@ Philippe Bruhat (BooK).
 
 =item *
 
+2012-10-29 - v1.008
+
+Updated from the source web site in Acme-MetaSyntactic-Themes version 1.025.
+
+=item *
+
 2012-10-22 - v1.007
 
 Updated from the source web site in Acme-MetaSyntactic-Themes version 1.024.
@@ -279,6 +285,7 @@ LinuxConsole
 linuX_gamers
 LinuxTLE
 Linvo
+Lite
 Litrix
 LliureX
 LPS
