@@ -2,7 +2,7 @@ package Acme::MetaSyntactic::pause_id;
 use strict;
 use Acme::MetaSyntactic::List;
 our @ISA = qw( Acme::MetaSyntactic::List );
-our $VERSION = '1.008';
+our $VERSION = '1.009';
 __PACKAGE__->init();
 
 our %Remote = (
@@ -35,6 +35,12 @@ Philippe Bruhat (BooK).
 
 =item *
 
+2012-11-05 - v1.009
+
+Updated from the source web site in Acme-MetaSyntactic-Themes version 1.026.
+
+=item *
+
 2012-10-29 - v1.008
 
 Updated from the source web site in Acme-MetaSyntactic-Themes version 1.025.
@@ -238,6 +244,7 @@ ACFEREN
 ACG
 ACH
 ACHEN
+ACHILLES
 ACHIMRU
 ACHOUNG
 ACID
@@ -402,6 +409,7 @@ AKIMOV
 AKIRA
 AKISSANE
 AKIYM
+AKMISHRA
 AKOBA
 AKOLB
 AKR
@@ -1437,6 +1445,7 @@ BURGERS
 BURKEY
 BURL
 BURNASH
+BURNERSK
 BUTILW
 BUU
 BUZZ
@@ -2604,6 +2613,7 @@ DREWF
 DREYNOLDS
 DRFROG
 DRIEUX
+DRIN
 DRINCHEV
 DRIPLOCK
 DRLARO
@@ -4584,6 +4594,7 @@ JMATES
 JMAY
 JMBO
 JMCADA
+JMCCARV
 JMCGUIRE
 JMCNAMARA
 JMEGERMAN
@@ -5014,6 +5025,7 @@ KAZEBURO
 KAZIMIROV
 KAZUHISA
 KAZUHO
+KAZUKIMA
 KAZUNORI
 KBA
 KBALBI
@@ -6092,6 +6104,7 @@ MEH
 MEHNER
 MEINTEUCH
 MEIRM
+MEKK
 MELE
 MELEZHIK
 MELLERY
@@ -8271,6 +8284,7 @@ SATANAIL
 SATHIYA
 SATKINS
 SATOH
+SATOSIN
 SATRAC
 SATZZ
 SAUBER
@@ -8333,6 +8347,7 @@ SCHWIGON
 SCIO
 SCL
 SCLOUSE
+SCM
 SCOLINET
 SCOOBY
 SCOOK
@@ -8494,6 +8509,7 @@ SHELLING
 SHELLTUX
 SHEMYAK
 SHENJ
+SHENSAP
 SHERLOCK
 SHERM
 SHERWIN
@@ -8778,6 +8794,7 @@ SORHED
 SORO
 SORTIZ
 SOTONA
+SOTSA
 SOURCERER
 SOVA
 SOZIN
@@ -8863,6 +8880,7 @@ SRSHAH
 SRUSHE
 SRVANCE
 SRYLE
+SRYNOBIO
 SRZ
 SSAAMM
 SSANTY
@@ -8922,6 +8940,7 @@ STEPHEN
 STEPHENC
 STEPHENCA
 STEPHENLB
+STEPHWEN
 STERLING
 STERLPERL
 STEVAN
@@ -9204,6 +9223,7 @@ TEKFU
 TELIN
 TELKINS
 TELS
+TEMA
 TEMPALTE
 TEMPIRE
 TEMPLER
@@ -9950,6 +9970,7 @@ WOODY
 WOOSTER
 WOREMACX
 WORENKD
+WORLDMIND
 WORM
 WORR
 WORRALL
@@ -10178,6 +10199,7 @@ YVES
 YVESAGO
 YVESP
 YWANGPERL
+YWATASE
 YXES
 ZABA
 ZABEL
